@@ -2,8 +2,6 @@
  * pptpctrl.h
  *
  * PPTP control function prototypes.
- *
- * $Id: pptpctrl.h,v 1.1.1.1 2002/06/21 08:52:01 fenix_nl Exp $
  */
 
 #ifndef _PPTPD_PPTPCTRL_H
@@ -11,4 +9,10 @@
 
 extern int pptpctrl_debug;
 
-#endif	/* !_PPTPD_PPTPCTRL_H */
+#ifdef VRF
+extern char *vrf;
+#else
+#define vrf_socket(vrf, dom, typ, prot) socket(dom, typ, prot)
+#endif
+
+#endif  /* !_PPTPD_PPTPCTRL_H */
